@@ -41,6 +41,9 @@ FAILEDOPERATION_NOTRTMPFUNCTION = 'FailedOperation.NotRtmpFunction'
 # 查询任务失败
 FAILEDOPERATION_QUERYTASKINFOFAILED = 'FailedOperation.QueryTaskInfoFailed'
 
+# 请求过期。
+FAILEDOPERATION_REQUESTOUTDATED = 'FailedOperation.RequestOutdated'
+
 # 云API混流模板和SDK混流冲突。
 FAILEDOPERATION_REQUESTREJECTION = 'FailedOperation.RequestRejection'
 
@@ -53,12 +56,21 @@ FAILEDOPERATION_ROOMNOTEXIST = 'FailedOperation.RoomNotExist'
 # 应用ID不存在。
 FAILEDOPERATION_SDKAPPIDNOTEXIST = 'FailedOperation.SdkAppIdNotExist'
 
+# AppId下没有此SdkAppId的资源
+FAILEDOPERATION_SDKAPPIDNOTUNDERAPPID = 'FailedOperation.SdkAppIdNotUnderAppId'
+
+# SdkAppId未开通页面录制能力，请检查。
+FAILEDOPERATION_SDKAPPIDNOTWEBRECORDABILITY = 'FailedOperation.SdkAppIdNotWebRecordAbility'
+
 # 任务已存在
 FAILEDOPERATION_TASKEXIST = 'FailedOperation.TaskExist'
 
 # 调用接口时任务已结束。
 FAILEDOPERATION_TASKFINISHED = 'FailedOperation.TaskFinished'
 
+# 任务不存在或已结束
+FAILEDOPERATION_TASKNOTEXIST = 'FailedOperation.TaskNotExist'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -119,6 +131,9 @@ INVALIDPARAMETER_ENCODEPARAMS = 'InvalidParameter.EncodeParams'
 # EndTs参数错误。
 INVALIDPARAMETER_ENDTS = 'InvalidParameter.EndTs'
 
+# invalid sdkAppId
+INVALIDPARAMETER_INVALIDSDKAPPID = 'InvalidParameter.InvalidSdkAppId'
+
 # 大画面居右显示参数错误。
 INVALIDPARAMETER_MAINVIDEORIGHTALIGN = 'InvalidParameter.MainVideoRightAlign'
 
